# -*- coding: utf-8 -*-
"""
Created on Mon Jul 29 11:12:10 2019

@author: Skills Cafe
"""

# Example Package

A powerful package to work on IoT projects.
This Package is specially designed for ESP32 boards.
Where ESP32 boards communicates via BLE. 
So there is one Server ESP32 Node which communicates to the Client ESP32.
Server ESP32 node is interfaced to PC through serial communication.

This package facilitates the entire communication happening with specific Skills Cafe Protocol.


